import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { DeviceService } from './device.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const DeviceUncheckedCreateInputSchema: ZodType<Prisma.DeviceUncheckedCreateInput> =
  z.any();
const DeviceWhereInputSchema: ZodType<Prisma.DeviceWhereInput> = z.any();
const DeviceSelectSchema: ZodType<Prisma.DeviceSelect> = z.any();
const DeviceUpdateArgsSchema: ZodType<Prisma.DeviceUpdateArgs> = z.any();
const DeviceFindFirstArgsSchema: ZodType<Prisma.DeviceFindFirstArgs> = z.any();
const DeviceFindManyArgsSchema: ZodType<Prisma.DeviceFindManyArgs> = z.any();

@Injectable()
export class DeviceRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly deviceService: DeviceService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(DeviceUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        console.log(input);
        return this.deviceService.create({ data: input });
      }),
    update: this.trpc.procedure
      .input(DeviceUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.deviceService.update(input);
      }),
    findMany: this.trpc.procedure
      .input(DeviceFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.deviceService.findMany(input);
      }),
    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.deviceService.softDeleteByIds(input.ids);
      }),
    findFirst: this.trpc.procedure
      .input(DeviceFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.deviceService.findFirst(input);
      }),
  });
}
