import { AppConfigSlug, BaseSetting, RolePerms } from "@nice/common";
import { useContext, useEffect, useState } from "react";
import {
  Button,
  Form,
  Input,
  message,
  theme,
  Card,
  Divider,
  Typography,
} from "antd";
import { useAppConfig } from "@nice/client";
import { useAuth } from "@web/src/providers/auth-provider";
import FixedHeader from "@web/src/components/layout/fix-header";
import { useForm } from "antd/es/form/Form";
import { api } from "@nice/client";
import { MainLayoutContext } from "../layout";
import DeviceManager from "../../main/devicepage/select/Device-manager";

const { Title, Paragraph } = Typography;

export default function BaseSettingPage() {
  const { update, baseSetting } = useAppConfig();
  const utils = api.useUtils();
  const [form] = useForm();
  const { token } = theme.useToken();
  const { data: clientCount } = api.app_config.getClientCount.useQuery(
    undefined,
    {
      refetchInterval: 3000,
      refetchIntervalInBackground: true,
    }
  );
  const [isFormChanged, setIsFormChanged] = useState(false);
  const [loading, setLoading] = useState(false);
  const { user, hasSomePermissions } = useAuth();
  const context = useContext(MainLayoutContext);
  const pageWidth = context?.pageWidth;

  function handleFieldsChange() {
    setIsFormChanged(true);
  }

  function onResetClick() {
    if (!form) return;
    if (!baseSetting) {
      form.resetFields();
    } else {
      form.resetFields();
      form.setFieldsValue(baseSetting);
    }
    setIsFormChanged(false);
  }

  function onSaveClick() {
    if (form) form.submit();
  }

  async function onSubmit(values: BaseSetting) {
    setLoading(true);
    const appConfig = values?.appConfig || {};
    try {
      await update.mutateAsync({
        where: {
          slug: AppConfigSlug.BASE_SETTING,
        },
        data: {
          meta: {
            ...baseSetting,
            appConfig: {
              ...(baseSetting?.appConfig || {}),
              ...appConfig,
            },
          },
        },
      });
      setIsFormChanged(false);
      message.success("已保存");
    } catch (err: any) {
      console.error(err);
    } finally {
      setLoading(false);
    }
  }

  useEffect(() => {
    if (baseSetting && form) {
      form.setFieldsValue(baseSetting);
    }
  }, [baseSetting, form]);

  return (
    <div style={{ width: pageWidth }}>
      <FixedHeader>
        <div className="flex items-center gap-2">
          {isFormChanged &&
            hasSomePermissions(RolePerms.MANAGE_BASE_SETTING) && (
              <>
                <Button onClick={onResetClick}>重置</Button>
                <Button loading={loading} type="primary" onClick={onSaveClick}>
                  保存
                </Button>
              </>
            )}
        </div>
      </FixedHeader>

      <div
        className="flex flex-col overflow-auto p-4"
        style={{ height: "calc(100vh - 48px - 49px)" }}
      >
        <Card bordered={false}>
          <Typography>
            <Title level={4}>网系故障分类管理</Title>
            <Paragraph>
              在此页面您可以管理网系故障的分类体系。系统会自动建立三层关系：网系类别
              → 故障类型 →
              具体故障名称。使用树形结构可以清晰地查看和管理这些分类关系。
            </Paragraph>
          </Typography>

          <Divider />

          <DeviceManager title="网系故障分类" />
        </Card>
      </div>
    </div>
  );
}
