// apps/web/src/components/models/term/system-type-select.tsx
import { Select } from "antd";
import { api } from "@nice/client";
import React from "react";

interface SystemTypeSelectProps {
  value?: string;
  onChange?: (value: string) => void;
  placeholder?: string;
  disabled?: boolean;
  className?: string;
  style?: React.CSSProperties;
}

export default function SystemTypeSelect({
  value,
  onChange,
  placeholder = "选择网系类别",
  disabled = false,
  className,
  style,
}: SystemTypeSelectProps) {
  const { data: terms, isLoading } = api.term.findMany.useQuery({
    where: {
      taxonomy: { slug: "system_type" },
      deletedAt: null,
      parentId: null, // 只查询顶级网系类别
    },
    orderBy: { order: "asc" },
  });

  const options =
    terms?.map((term) => ({
      label: term.name,
      value: term.id,
    })) || [];

  return (
    <Select
      loading={isLoading}
      value={value}
      onChange={onChange}
      options={options}
      placeholder={placeholder}
      disabled={disabled}
      className={className}
      style={style}
      showSearch
      filterOption={(input, option) =>
        (option?.label?.toString() || "")
          .toLowerCase()
          .includes(input.toLowerCase())
      }
      allowClear
    />
  );
}
